@@ -15,7 +15,7 @@ import time
 import cgi
 import os
 import webbrowser
-from Cookie import SimpleCookie
+from Cookie import BaseCookie
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -157,6 +157,8 @@ class TestApp(object):
         # @@: Should this be all non-strings?
         if isinstance(params, (list, tuple, dict)):
             params = urllib.urlencode(params)
+        if hasattr(params, 'items'):
+            params = urllib.urlencode(params.items())
         if upload_files:
             params = cgi.parse_qsl(params, keep_blank_values=True)
             content_type, params = self.encode_multipart(
@@ -283,7 +285,7 @@ class TestApp(object):
         errors = StringIO()
         req.environ['wsgi.errors'] = errors
         if self.cookies:
-            c = SimpleCookie()
+            c = BaseCookie()
             for name, value in self.cookies.items():
                 c[name] = value
             req.environ['HTTP_COOKIE'] = str(c).split(': ', 1)[1]
@@ -319,7 +321,7 @@ class TestApp(object):
             self._check_errors(res)
         res.cookies_set = {}
         for header in res.headers.getall('set-cookie'):
-            c = SimpleCookie(header)
+            c = BaseCookie(header)
             for key, morsel in c.items():
                 self.cookies[key] = morsel.value
                 res.cookies_set[key] = morsel.value
@@ -804,12 +806,12 @@ class TestResponse(Response):
             raise ImportError(
                 "You must have lxml installed to use response.lxml")
         try:
-            from lxml.html import HTML
+            from lxml.html import fromstring
         except ImportError:
-            HTML = etree.HTML
+            fromstring = etree.HTML
         ## FIXME: would be nice to set xml:base, in some fashion
         if self.content_type == 'text/html':
-            return HTML(self.body)
+            return fromstring(self.body)
         else:
             return etree.XML(self.body)
 
@@ -853,15 +855,6 @@ class TestRequest(Request):
 
     # for py.test
     disabled = True
-
-    def blank(cls, path_info, *args, **kw):
-        scheme, netloc, path, query, fragment = urlparse.urlsplit(path_info)
-        path_info = path + query
-        return super(TestRequest, cls).blank(
-            path_info, *args, **kw)
-
-    blank = classmethod(blank)
-
     ResponseClass = TestResponse
 
 ########################################
@@ -1255,6 +1248,8 @@ Field.classes['submit'] = Submit
 
 Field.classes['button'] = Submit
 
+Field.classes['image'] = Submit
+
 ########################################
 ## Utility functions
 ########################################
